@@ -9,7 +9,7 @@ use DateTime::Format::W3CDTF;
   
 use vars qw($VERSION $AUTOLOAD @ISA $AUTO_ADD);
 
-$VERSION = '1.21';
+$VERSION = '1.22';
 
 $AUTO_ADD = 0;
 
@@ -416,7 +416,16 @@ sub _get_default_modules
         'http://purl.org/rss/1.0/modules/syndication/' => 'syn',
         'http://purl.org/dc/elements/1.1/' => 'dc',
         'http://purl.org/rss/1.0/modules/taxonomy/' => 'taxo',
-    	'http://webns.net/mvcb/' => 'admin'
+    	'http://webns.net/mvcb/' => 'admin',
+        'http://purl.org/rss/1.0/modules/content/' => 'content',
+    };
+}
+
+sub _get_default_rss_2_0_modules
+{
+    return
+    {
+        'http://backend.userland.com/blogChannelModule' => 'blogChannel',
     };
 }
 
@@ -460,18 +469,23 @@ sub _initialize {
     $self->{namespaces} = {};
 	$self->{rss_namespace} = '';
 
+    #get version info
+    (exists($hash{version}))
+	? ($self->{version} = $hash{version})
+	    : ($self->{version} = '1.0');
+
     # modules
-    $self->{modules} = $self->_get_default_modules();
+    $self->{modules} =
+        (($self->{version} eq "2.0") ?
+            $self->_get_default_rss_2_0_modules() :
+            $self->_get_default_modules()
+        );
 
 	# encode output from as_string?
 	(exists($hash{encode_output}))
 	? ($self->{encode_output} = $hash{encode_output})
 		: ($self->{encode_output} = 1);
 
-    #get version info
-    (exists($hash{version}))
-	? ($self->{version} = $hash{version})
-	    : ($self->{version} = '1.0');
 
     # set default output
     (exists($hash{output}))
@@ -1385,7 +1399,16 @@ sub as_rss_2_0 {
 
     # RSS root element
     # $output .= '<rss version="0.91">'."\n\n";
-    $output .= '<rss version="2.0" xmlns:blogChannel="http://backend.userland.com/blogChannelModule">' . "\n\n";
+    
+    # RSS namespaces declaration
+    $output .= q[<rss version="2.0"] . "\n";
+ 
+     # print all imported namespaces
+    while (my($k, $v) = each %{$self->{modules}}) {
+        $output.=" xmlns:$v=\"$k\"\n";
+    }
+ 
+    $output .=">"."\n\n";
 
     ###################
     # Channel Element #
@@ -1449,7 +1472,22 @@ sub as_rss_2_0 {
         $output .= '<ttl>'.$self->_encode($self->{channel}->{ttl}).'</ttl>'."\n";
     }
 
-
+    # Ad-hoc modules
+    while ( my($url, $prefix) = each %{$self->{modules}} ) {
+        next if $prefix =~ /^(dc|syn|taxo)$/;
+        while ( my($el, $value) = each %{$self->{channel}->{$prefix}} ) {
+            if ( exists( $rdf_resource_fields{ $url } ) and
+                 exists( $rdf_resource_fields{ $url }{ $el }) )
+            {
+                $output .= "<$prefix:$el rdf:resource=\"" .
+                           $self->_encode($value) .
+                           "\" />\n";
+            }
+            else {
+                $output .= "<$prefix:$el>".  $self->_encode($value) ."</$prefix:$el>\n";
+            }
+        }
+    }
 
     $output .= "\n";
 
@@ -1469,6 +1507,23 @@ sub as_rss_2_0 {
             [qw(link width height description)]
         );
 
+        # Ad-hoc modules for images
+        while ( my($url, $prefix) = each %{$self->{modules}} ) {
+            next if $prefix =~ /^(dc|syn|taxo)$/;
+            while ( my($el, $value) = each %{$self->{image}->{$prefix}} ) {
+                if ( exists( $rdf_resource_fields{ $url } ) and
+                     exists( $rdf_resource_fields{ $url }{ $el }) )
+                {
+                    $output .= qq{<$prefix:$el rdf:resource="} .
+                               $self->_encode($value) .
+                               qq{" />\n};
+                }
+                else {
+                    $output .= "<$prefix:$el>".  $self->_encode($value) ."</$prefix:$el>\n";
+                }
+            }
+        }
+
         # end image element
         $output .= '</image>'."\n\n";
     }
@@ -1510,6 +1565,23 @@ sub as_rss_2_0 {
                     . ' />' . "\n";
             }
 
+            # Ad-hoc modules
+            while ( my($url, $prefix) = each %{$self->{modules}} ) {
+                next if $prefix =~ /^(dc|syn|taxo)$/;
+                while ( my($el, $value) = each %{$item->{$prefix}} ) {
+                    if ( exists( $rdf_resource_fields{ $url } ) and
+                         exists( $rdf_resource_fields{ $url }{ $el }) )
+                    {
+                        $output .= "<$prefix:$el rdf:resource=\"" .
+                                   $self->_encode($value) .
+                                   "\" />\n";
+                    }
+                    else {
+                        $output .= "<$prefix:$el>".  $self->_encode($value) ."</$prefix:$el>\n";
+                    }
+                }
+            }
+
             # end image element
             $output .= '</item>'."\n\n";
     }
@@ -1631,6 +1703,10 @@ sub handle_char {
     } elsif (
 	     $self->within_element("textinput")
 	     || $self->within_element($self->generate_ns_name("textinput",$self->{rss_namespace}))
+	     # textinput is spelled textInput (with a capital "I") in RSS 2.0
+	     || $self->within_element("textInput")
+	     || $self->within_element($self->generate_ns_name("textInput",$self->{rss_namespace}))
+         
 	) {
 		my $ns = $self->namespace($self->current_element);
 
@@ -1863,6 +1939,15 @@ sub _auto_add_modules {
 sub parse {
     my $self = shift;
     $self->_initialize((%$self));
+
+    # Workaround to make sure that if we were defined with version => "2.0"
+    # then we can still parse 1.0 and 0.9.x feeds correctly. 
+    if ($self->{version} eq "2.0")
+    {
+        $self->{modules} =
+           +{%{$self->_get_default_modules()}, %{$self->{modules}}};
+    }
+    
 	$self->SUPER::parse(shift);
     $self->_auto_add_modules if $AUTO_ADD;
     $self->{version} = $self->{_internal}->{version};
@@ -1871,6 +1956,15 @@ sub parse {
 sub parsefile {
     my $self = shift;
 	$self->_initialize((%$self));
+
+    # Workaround to make sure that if we were defined with version => "2.0"
+    # then we can still parse 1.0 and 0.9.x feeds correctly. 
+    if ($self->{version} eq "2.0")
+    {
+        $self->{modules} =
+           +{%{$self->_get_default_modules()}, %{$self->{modules}}};
+    }
+    
     $self->SUPER::parsefile(shift);
     $self->_auto_add_modules if $AUTO_ADD;
     $self->{version} = $self->{_internal}->{version};
